==> eiffelstudio-23.09.10.7341.tar: F_code/C2/by66.c <==
/*
 * Code for class BYTE_ARRAY_HELPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "by66.h"
#include "eif_built_in.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BYTE_ARRAY_HELPER}.put_array_natural_16 */
void F68_2124 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_natural_16", 67, Current, 3, 3, 1512);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3135, 0x00).id, 3135, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3136_34541(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3136_34601(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3136_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3009_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3009_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_array_natural_32 */
void F68_2128 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_natural_32", 67, Current, 3, 3, 1516);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3135, 0x00).id, 3135, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3136_34541(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3136_34602(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3136_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3009_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3009_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_array_natural_32_with_integer_32 */
void F68_2130 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_natural_32_with_integer_32", 67, Current, 3, 3, 1492);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3135, 0x00).id, 3135, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3136_34541(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3136_34606(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3136_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3009_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3009_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_array_integer_16 */
void F68_2133 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_integer_16", 67, Current, 3, 3, 1495);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3135, 0x00).id, 3135, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3136_34541(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3136_34605(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3136_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3009_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3009_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

void EIF_Minit66 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C2/by66.c <==
/*
 * Code for class BYTE_ARRAY_HELPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "by66.h"
#include "eif_built_in.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BYTE_ARRAY_HELPER}.put_natural_16 */
void F67_2096 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_natural_16", 66, Current, 3, 3, 1475);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3151, 0x00).id, 3151, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3152_34648(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3152_34708(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3152_34675(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3025_33965(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3025_33973(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_natural_32 */
void F67_2097 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_natural_32", 66, Current, 3, 3, 1476);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3151, 0x00).id, 3151, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3152_34648(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3152_34709(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3152_34675(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3025_33965(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3025_33973(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_integer_16 */
void F67_2100 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_integer_16", 66, Current, 3, 3, 1479);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3151, 0x00).id, 3151, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3152_34648(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3152_34712(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3152_34675(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3025_33965(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3025_33973(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_integer_32 */
void F67_2101 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_integer_32", 66, Current, 3, 3, 1480);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3151, 0x00).id, 3151, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3152_34648(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3152_34713(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3152_34675(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3025_33965(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3025_33973(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

void EIF_Minit66 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
